### Name: keremRand
### Title: Psudo-subjects from Kerem's Cystic Fibrosis Data
### Aliases: keremRandSeq keremRandStatus keremRandAllele
### Keywords: datasets

### ** Examples

## Not run: 
##D ## Here are how the psudo-subjects are simulated
##D #### loading HapVLMC package and the dataset
##D library(HapVLMC)
##D data(Kerem)
##D set.seed(20090313)
##D randOrder <- runif(nrow(kerem.snps.data))
##D keremRandSeq <- rbind(## randomly order the TRUE part
##D                    kerem.snps.data[kerem.status, ][order(randOrder[kerem.status]), ],
##D                    ## randomly order the FALSE part
##D                    kerem.snps.data[!kerem.status, ][order(randOrder[!kerem.status]), ]
##D                    )
##D 
##D nLoci <- ncol(keremRandSeq)
##D lociNum <- unlist(sapply(1:nLoci, 
##D            function(x){
##D                 paste(paste(
##D                         rep("0", ceiling(log10(nLoci)) - nchar(as.character(x))), collapse=""),
##D                         x, sep="", collapse="")
##D                         })
##D                  )
##D colnames(keremRandSeq) <- paste("locus_", lociNum, sep="")
##D 
##D nSubj <- nrow(keremRandSeq)/2
##D subjNum <- unlist(sapply(1:nSubj, 
##D            function(x){
##D                 paste(paste(
##D                         rep("0", ceiling(log10(nSubj)) - nchar(as.character(x))), collapse=""),
##D                         x, sep="", collapse="")
##D                         })
##D                  )
##D subjLabel <- paste("subj_", subjNum, sep="")
##D seqLabel <- paste("seq", 1:2, sep="_")
##D rownames(keremRandSeq) <- paste(rep(subjLabel, each=2), seqLabel, sep="_")
##D 
##D keremRandStatus <- c(rep(1, sum(kerem.status)/2), rep(0, sum(!kerem.status)/2))
##D 
##D keremRandAllele <- NULL
##D for(i in seq(1, nrow(keremRandSeq), by=2)){
##D     keremRandAllele <- rbind(keremRandAllele,
##D                        apply(keremRandSeq[c(i, i+1), ], 2,
##D                              function(x){
##D                                  ## counting how many small alleles
##D                                  sum(x==2)
##D                              }
##D                              )
##D                        )
##D }
##D rownames(keremRandAllele) <- unique(gsub("^(subj_.*)_seq_(.*)$", "\1", rownames(keremRandSeq)))
## End(Not run)

## load keremRand
data(keremRand)

## check which objects are attached 
ls()

## dimention of psedu-subject data
dim(keremRandSeq)

## number of CF (TRUE) and control (FALSE) subjects
table(keremRandStatus)



